@@ -11,7 +11,6 @@
 dbg_error_log("POST", "method handler");
 
 require_once("XMLDocument.php");
-require_once("iCalendar.php");
 include_once('caldav-PUT-functions.php');
 include_once('freebusy-functions.php');
 
@@ -60,7 +59,7 @@ function handle_freebusy_request( $ic ) {
     $attendee_email = preg_replace( '/^mailto:/', '', $attendee->Value() );
     dbg_error_log( "POST", "Calculating free/busy for %s", $attendee_email );
 
-    /** @TODO: Refactor this so we only do one query here and loop through the results */
+    /** @todo Refactor this so we only do one query here and loop through the results */
     $params = array( ':session_principal' => $session->principal_id, ':scan_depth' => $c->permission_scan_depth, ':email' => $attendee_email );
     $qry = new AwlQuery('SELECT pprivs(:session_principal::int8,principal_id,:scan_depth::int) AS p, username FROM usr JOIN principal USING(user_no) WHERE lower(usr.email) = lower(:email)', $params );
     if ( !$qry->Exec('POST',__LINE__,__FILE__) ) $request->DoResponse( 501, 'Database error');
@@ -97,8 +96,7 @@ function handle_freebusy_request( $ic ) {
     $fb->SetProperties( $ic->GetProperties('ORGANIZER'), 'ORGANIZER');
     $fb->AddProperty( $attendee );
 
-    $vcal = new iCalComponent();
-    $vcal->VCalendar( array('METHOD' => 'REPLY') );
+    $vcal = new vCalendar( array('METHOD' => 'REPLY') );
     $vcal->AddComponent( $fb );
 
     $response = $reply->NewXMLElement( "response", false, false, 'urn:ietf:params:xml:ns:caldav' );
@@ -124,7 +122,7 @@ function handle_cancel_request( $ic ) {
   $request->XMLResponse( 200, $response );
 }
 
-$ical = new iCalComponent( $request->raw_post );
+$ical = new vComponent( $request->raw_post );
 $method =  $ical->GetPValue('METHOD');
 
 $resources = $ical->GetComponents('VTIMEZONE',false);
